===========
pythonGraph
===========

pythonGraph is a simple graphics package for Python. Its design is loosely
descended from Adagraph and RAPTOR Graph. pythonGraph supports the creation of
a graphics window, the display of simple geometric shapes, and simple user
interactions using the mouse and keyboard.

pythonGraph is designed for introductory programming courses, allowing students
to create a graphical user interface with minimal complexity.

License
=======

This material is a United States government work (prepared by officers and
employees of the U.S. Government as part of their official duties) and is not
protected by copyright in the U.S. (17 U.S.C. Section 105) and may be used
without obtaining permission.
